package com.ruoyi.web.v2.v1.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.web.v2.v1.entity.JsCheckProject;
import com.ruoyi.web.v2.v1.entity.JsDisinfectManage;
import com.ruoyi.web.v2.v1.mapper.JsCheckProjectMapper;
import com.ruoyi.web.v2.v1.service.IJsCheckProjectService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import static com.ruoyi.common.core.domain.AjaxResult.error;
import static com.ruoyi.common.core.domain.AjaxResult.success;

/**
 * <p>
 * 2.0检验项目管理 服务实现类
 * </p>
 *
 * @author author
 * @since 2025-05-20
 */
@Service
public class JsCheckProjectServiceImpl extends ServiceImpl<JsCheckProjectMapper, JsCheckProject> implements IJsCheckProjectService {

    @Autowired
    private JsCheckProjectMapper projectMapper;

    @Override
    public AjaxResult add(JsCheckProject checkProject) {
        String projectName = checkProject.getProjectName();
        Integer count = projectMapper.selectCount(new QueryWrapper<JsCheckProject>().eq("project_name", projectName));
        if (count != 0) {
            return error("消毒方式已存在！");
        } else {
            projectMapper.insert(checkProject);
        }
        return success("添加成功");
    }

    @Override
    public AjaxResult edit(JsCheckProject checkProject) {
        String projectName = checkProject.getProjectName();
        Integer count = projectMapper.selectCount(new QueryWrapper<JsCheckProject>().eq("project_name", projectName).ne("id",checkProject.getId()));
        if (count != 0) {
            return error("消毒方式已存在！");
        } else {
            projectMapper.updateById(checkProject);
        }
        return success("修改成功");
    }

    @Override
    public AjaxResult delete(String ids) {
        String[] split = ids.split(",");
        for (String s : split) {
            projectMapper.deleteById(s);
        }
        return success("删除成功");
    }

    @Override
    public AjaxResult page(Integer pageNum, Integer pageSize, String projectName) {
        QueryWrapper<JsCheckProject> queryWrapper = new QueryWrapper<>();
        Page<JsCheckProject> page = new Page<>(pageNum, pageSize);
        queryWrapper.like(StringUtils.isNotEmpty(projectName), "project_name", projectName);
        return success(projectMapper.selectPage(page, queryWrapper));
    }

    @Override
    public AjaxResult listAll() {
        return success(projectMapper.selectList(null));
    }
}
