package com.ruoyi.web.v2.v1.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ruoyi.app.domain.EntranceBatch;
import com.ruoyi.app.domain.HarmlessTreatment;
import com.ruoyi.app.domain.Pigpen;
import com.ruoyi.app.mapper.EntranceBatchMapper;
import com.ruoyi.app.mapper.HarmlessTreatmentMapper;
import com.ruoyi.app.mapper.PigpenMapper;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.web.v2.v1.entity.JsDivideCircle;
import com.ruoyi.web.v2.v1.mapper.JsDivideCircleMapper;
import com.ruoyi.web.v2.v1.service.IJsDivideCircleService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;

import static com.ruoyi.common.core.domain.AjaxResult.error;
import static com.ruoyi.common.core.domain.AjaxResult.success;

/**
 * <p>
 * v2.0分圈登记 服务实现类
 * </p>
 *
 * @author author
 * @since 2025-05-22
 */
@Service
public class JsDivideCircleServiceImpl extends ServiceImpl<JsDivideCircleMapper, JsDivideCircle> implements IJsDivideCircleService {

    @Autowired
    private JsDivideCircleMapper jsDivideCircleMapper;
    @Autowired
    private PigpenMapper pigpenMapper;
    @Autowired
    private HarmlessTreatmentMapper harmlessTreatmentMapper;
    @Autowired
    private EntranceBatchMapper entranceBatchMapper;

    @Override
    public AjaxResult add(JsDivideCircle divideCircle) {
        Pigpen pigpen = pigpenMapper.selectPigpenById(divideCircle.getPigpenId().longValue());
        if (pigpen.getIsUse() != 0) {
            return error("新增失败，该待宰圈已被使用");
        }

        HarmlessTreatment harmlessTreatment = harmlessTreatmentMapper.selectByEntraceBatchId(divideCircle.getEntranceBatchId().longValue());
        if (ObjectUtil.isEmpty(harmlessTreatment)) {
            return error("未进行无害化处理");
        }
        int batch = entranceBatchMapper.deleteEntranceBatchById(divideCircle.getEntranceBatchId().longValue());

        divideCircle.setCreateTime(new Date());
        jsDivideCircleMapper.insert(divideCircle);
        pigpen.setIsUse(1);
        pigpenMapper.updatePigpen(pigpen);
        return success();
    }

    @Override
    public AjaxResult edit(JsDivideCircle divideCircle) {
        jsDivideCircleMapper.updateById(divideCircle);
        return success();
    }

    @Override
    public AjaxResult delete(String ids) {
        String[] split = ids.split(",");
        for (String s : split) {
            JsDivideCircle jsDivideCircle = jsDivideCircleMapper.selectById(s);
            Pigpen pigpen = pigpenMapper.selectPigpenById(jsDivideCircle.getPigpenId().longValue());
            pigpen.setIsUse(0);
            pigpenMapper.updatePigpen(pigpen);
            jsDivideCircleMapper.deleteById(s);
        }
        return success();
    }

    @Override
    public AjaxResult page(Integer pageNum, Integer pageSize, String startTime,String endTime, String pigpenName) {
        Page<JsDivideCircle> page = new Page<>(pageNum, pageSize);
        QueryWrapper<JsDivideCircle> queryWrapper = new QueryWrapper<>();
        if ("".equals(startTime) || null == startTime) {

        } else {
            queryWrapper.between("divide_time", startTime, endTime);
        }
        queryWrapper.like(StringUtils.isNotEmpty(pigpenName),"pigpen_name", pigpenName);
        return success(jsDivideCircleMapper.selectPage(page, queryWrapper));
    }

    @Override
    public AjaxResult listAll() {
        return success(jsDivideCircleMapper.selectList(null));
    }

}
