package com.ruoyi.web.v2.v1.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.web.v2.v1.entity.JsInStock;
import com.ruoyi.web.v2.v1.entity.JsInstrumentMaintenance;
import com.ruoyi.web.v2.v1.entity.JsStock;
import com.ruoyi.web.v2.v1.mapper.JsInStockMapper;
import com.ruoyi.web.v2.v1.mapper.JsStockMapper;
import com.ruoyi.web.v2.v1.service.IJsInStockService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;

import static com.ruoyi.common.core.domain.AjaxResult.success;

/**
 * <p>
 * v2.0物料入库 服务实现类
 * </p>
 *
 * @author author
 * @since 2025-05-23
 */
@Service
public class JsInStockServiceImpl extends ServiceImpl<JsInStockMapper, JsInStock> implements IJsInStockService {

    @Autowired
    private JsInStockMapper inStockMapper;
    @Autowired
    private JsStockMapper stockMapper;

    @Override
    public AjaxResult add(JsInStock inStock) {
        String materialBatch = inStock.getMaterialBatch();
        QueryWrapper<JsStock> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("material_batch", materialBatch);
        JsStock jsStock = stockMapper.selectOne(queryWrapper);
        if (ObjectUtil.isEmpty(jsStock)) {
            JsStock jsStock1 = new JsStock();
            jsStock1.setMaterialBatch(materialBatch);
            jsStock1.setLocation(inStock.getLocation());
            jsStock1.setMaterialName(inStock.getMaterialName());
            jsStock1.setMaterialType(inStock.getMaterialType());
            jsStock1.setModel(inStock.getModel());
            jsStock1.setSaveCondition(inStock.getSaveCondition());
            jsStock1.setSaveUser(inStock.getSaveUser());
            jsStock1.setStockAmount(inStock.getStockAmount());
            jsStock1.setUnit(inStock.getUnit());
            jsStock1.setUpdateTime(new Date());
            stockMapper.insert(jsStock1);
        } else {
            String stockAmount = jsStock.getStockAmount();
            double v = Double.valueOf(stockAmount) + Double.valueOf(inStock.getStockAmount());
            jsStock.setStockAmount(String.valueOf(v));
            jsStock.setUpdateTime(new Date());
            stockMapper.updateById(jsStock);
        }
        inStockMapper.insert(inStock);
        return success();
    }

    @Override
    public AjaxResult edit(JsInStock inStock) {
        String materialBatch = inStock.getMaterialBatch();
        JsInStock jsInStock = inStockMapper.selectById(inStock.getId());
        QueryWrapper<JsStock> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("material_batch", materialBatch);
        JsStock jsStock = stockMapper.selectOne(queryWrapper);
        double v = Double.valueOf(jsStock.getStockAmount()) - Double.valueOf(jsInStock.getStockAmount()) + Double.valueOf(inStock.getStockAmount());
        jsStock.setStockAmount(String.valueOf(v));
        stockMapper.updateById(jsStock);
        inStockMapper.updateById(inStock);
        return success();
    }

    @Override
    public AjaxResult delete(String ids) {
//        String[] split = ids.split(",");
//        for (String s : split) {
//            maintenanceMapper.deleteById(s);
//        }
        return success();
    }

    @Override
    public AjaxResult page(Integer pageNum, Integer pageSize, String startTime, String endTime, String materialBatch, String materialName, Integer materialType) {
        Page<JsInStock> page = new Page<>(pageNum, pageSize);
        QueryWrapper<JsInStock> queryWrapper = new QueryWrapper<>();
        if ("".equals(startTime) || null == startTime) {

        } else {
            queryWrapper.between("in_time", startTime, endTime);
        }
        queryWrapper.like(StringUtils.isNotEmpty(materialBatch), "material_batch", materialBatch)
                .or().like(StringUtils.isNotEmpty(materialName), "material_name", materialName);
        if (null != materialType) {
            queryWrapper.eq("material_type", materialType);
        }
        return success(inStockMapper.selectPage(page, queryWrapper));
    }

    @Override
    public AjaxResult listAll() {
        return success(inStockMapper.selectList(null));
    }
}
